using System;
using System.Data;
using Microsoft.SqlServer.Server;
using System.Data.SqlTypes;
using System.IO;
using System.Text;


//use clr serialization to serialize the intermediate result
//optimizer property
//optimizer property
//optimizer property
//maximum size in bytes of persisted value
[Serializable][SqlUserDefinedAggregate(Format.UserDefined, IsInvariantToNulls = true, IsInvariantToDuplicates = false, IsInvariantToOrder = false, MaxByteSize = 8000)]
public class ListAgg : IBinarySerialize
{
    private StringBuilder intermediateResult;
    //private static Int64 items;

    // Initialize the internal data structures
    public void Init()
    {
        this.intermediateResult = new StringBuilder();
    }

    // Accumulate the next value, not if the value is null
    public void Accumulate(SqlString value, SqlString delimiter, SqlString qualifier) // , SqlInt64 max_limit, SqlString limit_options)
    {
        if (value.IsNull)
        {
            return;
        }


        //set default values 
        qualifier = (qualifier == null ? "" : qualifier);
        delimiter = (delimiter == null ? "," : delimiter);

        this.intermediateResult.Append(qualifier + value.Value + qualifier).Append(delimiter);
    }

    // Merge the partially computed aggregate with this aggregate.
    public void Merge(ListAgg other)
    {
        this.intermediateResult.Append(other.intermediateResult);
    }

    // Called at the end of aggregation, to return the results of the aggregation.
    public SqlString Terminate()
    {
        string output = string.Empty;
        //delete the trailing comma, if any
        if (this.intermediateResult != null
            && this.intermediateResult.Length > 0)
        {
            output = this.intermediateResult.ToString(0, this.intermediateResult.Length - 1);
        }

        return new SqlString(output);
    }

    public void Read(BinaryReader r)
    {
        intermediateResult = new StringBuilder(r.ReadString());
    }

    public void Write(BinaryWriter w)
    {
        w.Write(this.intermediateResult.ToString());
    }
}
