using System.Collections;
using System.Data.SqlTypes;
using System.Text.RegularExpressions;
using Microsoft.SqlServer.Server;


namespace ClrRegEx
{
	public sealed class fn_regex
	{
        //clr.fn_regex_ismatch - Custom regex function, gets the result of a substring match; 
		[SqlFunction(DataAccess = DataAccessKind.None, IsDeterministic = true, IsPrecise = true, Name = "fn_regex_ismatch", SystemDataAccess = SystemDataAccessKind.None)]
		public static SqlBoolean RegExMatch(SqlString input, SqlString pattern, SqlBoolean ignoreCase)
		{
			//If inputs are null return null
			if (input.IsNull || pattern.IsNull)
			{
				return SqlBoolean.Null;
			}

			//Execute regex and return the result
			return new SqlBoolean(Regex.IsMatch(input.Value, pattern.Value, ignoreCase.Value ? RegexOptions.IgnoreCase : RegexOptions.None));
		}


        //clr.fn_regex_replace - Custom regex function, advanced replace based on regular expressions;
		[SqlFunction(DataAccess = DataAccessKind.None, IsDeterministic = true, IsPrecise = true, Name = "fn_regex_replace", SystemDataAccess = SystemDataAccessKind.None)]
		public static SqlString RegExReplace(SqlString input, SqlString pattern, SqlString replacement, SqlBoolean ignoreCase)
		{
			//If either input is NULL, return NULL
			if (input.IsNull || pattern.IsNull)
			{
				return SqlString.Null;
			}

			//Execute the regular expression and return the result
			return new SqlString(Regex.Replace(input.Value, pattern.Value, replacement.Value, ignoreCase.Value ? RegexOptions.IgnoreCase : RegexOptions.None));
		}


        //clr.fn_regex_matches - Custom regex function, returns the matching collection; 
		[SqlFunction(DataAccess = DataAccessKind.None, IsDeterministic = true, IsPrecise = true, Name = "fn_regex_matches", SystemDataAccess = SystemDataAccessKind.None, FillRowMethodName = "GetRegExMatches")]
		public static IEnumerable RegExMatches(SqlString input, SqlString pattern, SqlBoolean ignoreCase)
		{
			//If either input is NULL, return NULL
			if (input.IsNull || pattern.IsNull)
			{
				return null;
			}

			//Execute the regular expression and return the result
			return Regex.Matches(input.Value, pattern.Value, ignoreCase.Value ? RegexOptions.IgnoreCase : RegexOptions.None);
		}
		private static void GetRegExMatches(object input, out SqlString match, out SqlInt32 matchIndex, out SqlInt32 matchLength)
		{
			//Get a handle to the match object
			Match RegExMatch = (Match)input;

			//Set the column values
			match = new SqlString(RegExMatch.Value);
			matchIndex = new SqlInt32(RegExMatch.Index);
			matchLength = new SqlInt32(RegExMatch.Length);
		}

		//clr.fn_regex_split - Visual Basic like SPLIT function with advanced RegEx capabilities; 
        [SqlFunction(DataAccess = DataAccessKind.None, IsDeterministic = true, IsPrecise = true, Name = "fn_regex_split", SystemDataAccess = SystemDataAccessKind.None, FillRowMethodName = "GetRegExSplits")]
		public static IEnumerable RegExSplit(SqlString input, SqlString pattern, SqlBoolean ignoreCase)
		{
			//If either input is NULL, return NULL
			if (input.IsNull || pattern.IsNull)
			{
				return null;
			}

			//Execute the regular expression and return the result
			return Regex.Split(input.Value, pattern.Value, ignoreCase.Value ? RegexOptions.IgnoreCase : RegexOptions.None);
		}
		private static void GetRegExSplits(object input, out SqlString match)
		{
			//Set the match
			match = new SqlString((string)input);
		}

        //clr.fn_regex_occurs - Custom regex function, advanced occurs function using regular expressions to return the number of occurences
        [SqlFunction(DataAccess = DataAccessKind.None, IsDeterministic = true, IsPrecise = true, Name = "fn_regex_occurs", SystemDataAccess = SystemDataAccessKind.None)]
        public static int RegExOccurs(SqlString input, SqlString pattern, SqlBoolean ignoreCase)
        {
            //If inputs are null return null
            if (input.IsNull || pattern.IsNull)
            {
                return 0;
            }

            //Execute regex and return the result
            return (int)(Regex.Matches(input.Value, pattern.Value, ignoreCase.Value ? RegexOptions.IgnoreCase : RegexOptions.None).Count);  
         }


        //clr.fn_regex_instr - Custom regex function, returns the postion of regex expression in a string;
        //regex_like
        //regex_substr

        private fn_regex()
		{
			//Since all of the methods in this class are static, there is no need for a public constructor
		}
	}
}