USE Lib
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
----------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_count_val') BEGIN
	DROP  FUNCTION  tsql.fn_count_val
	PRINT '<<< DROP FUNCTION tsql.fn_count_val - Completed with SUCCESS >>>'
END
GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


/*================================================================================================
Name:			tsql.fn_count_val
Type:			User defined function 
Owner:					
Description:	Returns count of non-empty values from a coma sepparated list of values 
Parameters:		@list = list of values comma delimited
				@distinct = count distinct values only flag
Dependens on:  	fn_split
Usage:			SELECT [tsql].[fn_count_val] ('1,2,3,4,5',0)
--------------------------------------------------------------------------------------------------
Project:		http://sqllib.codeplex.com/
Help:			http://sqllib.codeplex.com/wikipage?title=fn_count_val&referringTitle=Documentation		
Version:		20120904
SrcCtrlApp:		SVN
SrcCtrlPath:	http://sqllib.codeplex.com/SourceControl/list/changesets
--------------------------------------------------------------------------------------------------
History:		09/04/2012 - Adrian E Dudau - Function created
================================================================================================*/

CREATE FUNCTION [tsql].[fn_count_val] (@list NVARCHAR(MAX), @distinct BIT = 0)
RETURNS BIGINT
AS

BEGIN
	RETURN (SELECT 'rcnt' = CASE WHEN @distinct = 1 THEN COUNT(DISTINCT item_value) ELSE COUNT(item_value) end FROM [tsql].[fn_split](@list,','));
END

GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
-- Verify completion
----------------------------
IF EXISTS(SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_count_val') BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_count_val - Completed with SUCCESS >>>'
END

ELSE BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_count_val - Completed with ERROR >>>'
END

GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

-- add security options here
-- add synonyms here
