USE Lib
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
----------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_distinct_val') BEGIN
	DROP  FUNCTION  tsql.fn_distinct_val
	PRINT '<<< DROP FUNCTION tsql.fn_distinct_val - Completed with SUCCESS >>>'
END
GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


/*================================================================================================
Name:			tsql.fn_distinct_val
Type:			User defined function 
Owner:					
Description:	Returns distinct list items from a coma sepparated list of values 
Parameters:		@list = list of values comma delimited
				@sort = specifies if/how the resulting list will be sorted
Dependens on:  	fn_split
Usage:			SELECT [tsql].[fn_distinct_val] ('1,2,2,2,3,4,5','ASC')
--------------------------------------------------------------------------------------------------
Project:		http://sqllib.codeplex.com/
Help:			http://sqllib.codeplex.com/wikipage?title=fn_distinct_val&referringTitle=Documentation		
Version:		20120904
SrcCtrlApp:		SVN
SrcCtrlPath:	http://sqllib.codeplex.com/SourceControl/list/changesets
--------------------------------------------------------------------------------------------------
History:		09/04/2012 - Adrian E Dudau - Function created
================================================================================================*/

CREATE FUNCTION [tsql].[fn_distinct_val] (@list NVARCHAR(MAX),@sort NVARCHAR(20) = NULL)
RETURNS NVARCHAR(MAX)
AS

BEGIN
	DECLARE @Result NVARCHAR(MAX)
	DECLARE @item_value NVARCHAR(4000)

	SET @result = ''

	IF ISNULL(@sort,'NOSORT') IN ('ASC','ASCENDING') BEGIN 
		DECLARE curs CURSOR FOR 
		SELECT DISTINCT item_value 
		FROM [tsql].[fn_split](@list,',')
		ORDER BY item_value ASC
	END
	 
	ELSE IF ISNULL(@sort,'NOSORT') IN ('DESC','DESCENDING') BEGIN 
		DECLARE curs CURSOR FOR 
		SELECT DISTINCT item_value 
		FROM [tsql].[fn_split](@list,',')
		ORDER BY item_value DESC
	END
	 
	ELSE BEGIN 
		DECLARE curs CURSOR FOR 
		SELECT item_value
		FROM [tsql].[fn_split](@list,',')
		GROUP BY item_value
		ORDER BY MIN(id)
	END
	 
	OPEN curs
	FETCH NEXT FROM curs INTO @item_value

	WHILE @@FETCH_STATUS = 0 BEGIN
	SELECT  @result = @result + CASE WHEN @result = '' THEN '' ELSE ',' END + @item_value
	FETCH NEXT FROM curs INTO @item_value
	END

	CLOSE curs
	DEALLOCATE curs

	RETURN @Result 
END

GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
-- Verify completion
----------------------------
IF EXISTS(SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_distinct_val') BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_distinct_val - Completed with SUCCESS >>>'
END

ELSE BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_distinct_val - Completed with ERROR >>>'
END

GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------


