USE Lib
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
----------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_list_delete') BEGIN
	DROP  FUNCTION  tsql.fn_list_delete
	PRINT '<<< DROP FUNCTION tsql.fn_list_delete - Completed with SUCCESS >>>'
END
GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


/*================================================================================================
Name:			tsql.fn_list_delete
Type:			User defined function 
Owner:					
Description:	Sorts the elements in a list ASCENDIND/DESCENDING   
Parameters:		@list = list of values comma delimited
				@where = where clause(allows wildcards)  
Dependens on:  	fn_split
Usage:			SELECT [tsql].[fn_list_delete] ('7,2,12,23,3,4,5',2)
--------------------------------------------------------------------------------------------------
Project:		http://sqllib.codeplex.com/
Help:			http://sqllib.codeplex.com/wikipage?title=fn_list_delete&referringTitle=Documentation		
Version:		20120905
SrcCtrlApp:		SVN
SrcCtrlPath:	http://sqllib.codeplex.com/SourceControl/list/changesets
--------------------------------------------------------------------------------------------------
History:		09/05/2012 - Adrian E Dudau - Function created
================================================================================================*/

CREATE FUNCTION [tsql].[fn_list_delete] (@list NVARCHAR(MAX),@where NVARCHAR(4000))
RETURNS NVARCHAR(MAX) 
AS

BEGIN /*FUNCTION*/
	DECLARE @Result NVARCHAR(MAX) = '';
	DECLARE @item_value NVARCHAR(MAX) = ''

	DECLARE curs CURSOR FOR 
			SELECT item_value   
    		FROM [tsql].[fn_split](@list,',')
			WHERE item_value NOT LIKE @where
	OPEN curs
	FETCH NEXT FROM curs INTO @item_value

	WHILE @@FETCH_STATUS = 0 BEGIN
		SELECT  @result = @result + CASE WHEN @result = '' THEN '' ELSE ',' END + @item_value
		FETCH NEXT FROM curs INTO @item_value
	END

	CLOSE curs
	DEALLOCATE curs
	
	RETURN @Result 
 END /*FUNCTION*/

GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
-- Verify completion
----------------------------
IF EXISTS(SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_list_delete') BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_list_delete - Completed with SUCCESS >>>'
END

ELSE BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_list_delete - Completed with ERROR >>>'
END

GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------


