USE Lib
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
----------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_list_sort') BEGIN
	DROP  FUNCTION  tsql.fn_list_sort
	PRINT '<<< DROP FUNCTION tsql.fn_list_sort - Completed with SUCCESS >>>'
END
GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


/*================================================================================================
Name:			tsql.fn_list_sort
Type:			User defined function 
Owner:					
Description:	Sorts the elements in a list ASCENDIND/DESCENDING   
Parameters:		@list = list of numeric values comma delimited
				@sort_descending = default 0, sorts ascending, 1 indicates ascending 
Dependens on:  	fn_split
Usage:			SELECT [tsql].[fn_list_sort] ('7,2,12,23,3,4,5')
--------------------------------------------------------------------------------------------------
Project:		http://sqllib.codeplex.com/
Help:			http://sqllib.codeplex.com/wikipage?title=fn_list_sort&referringTitle=Documentation		
Version:		20120905
SrcCtrlApp:		SVN
SrcCtrlPath:	http://sqllib.codeplex.com/SourceControl/list/changesets
--------------------------------------------------------------------------------------------------
History:		09/05/2012 - Adrian E Dudau - Function created
================================================================================================*/

CREATE FUNCTION [tsql].[fn_list_sort] (@list NVARCHAR(MAX),@sort_descending BIT = 0)
RETURNS NVARCHAR(MAX) 
AS

BEGIN /*FUNCTION*/
	DECLARE @Result NVARCHAR(MAX)
	DECLARE @item_value NVARCHAR(4000)

	SET @result = ''
	SET @sort_descending = ISNULL(@sort_descending,0)  
	
	IF @sort_descending = 0 BEGIN 
		DECLARE curs CURSOR FOR 
		SELECT item_value 
		FROM [tsql].[fn_split](@list,',')
		ORDER BY item_value ASC
	END
	 
	ELSE IF @sort_descending = 1 BEGIN 
		DECLARE curs CURSOR FOR 
		SELECT item_value 
		FROM [tsql].[fn_split](@list,',')
		ORDER BY item_value DESC
	END
	 	 
	OPEN curs
	FETCH NEXT FROM curs INTO @item_value

	WHILE @@FETCH_STATUS = 0 BEGIN
	SELECT  @result = @result + CASE WHEN @result = '' THEN '' ELSE ',' END + @item_value
	FETCH NEXT FROM curs INTO @item_value
	END

	CLOSE curs
	DEALLOCATE curs

	RETURN @Result END /*FUNCTION*/

GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
-- Verify completion
----------------------------
IF EXISTS(SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_list_sort') BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_list_sort - Completed with SUCCESS >>>'
END

ELSE BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_list_sort - Completed with ERROR >>>'
END

GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------


