USE Lib
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
----------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_list_update') BEGIN
	DROP  FUNCTION  tsql.fn_list_update
	PRINT '<<< DROP FUNCTION tsql.fn_list_update - Completed with SUCCESS >>>'
END
GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


/*================================================================================================
Name:			tsql.fn_list_update
Type:			User defined function 
Owner:					
Description:	Sorts the elements in a list ASCENDIND/DESCENDING   
Parameters:		@list = list of values comma delimited
				@value = value to update
				@where = where clause to use for update (allows wildcards)
Dependens on:  	fn_split
Usage:			SELECT [tsql].[fn_list_update] ('7,2,12,23,3,4,5','45',3)
--------------------------------------------------------------------------------------------------
Project:		http://sqllib.codeplex.com/
Help:			http://sqllib.codeplex.com/wikipage?title=fn_list_update&referringTitle=Documentation		
Version:		20120905
SrcCtrlApp:		SVN
SrcCtrlPath:	http://sqllib.codeplex.com/SourceControl/list/changesets
--------------------------------------------------------------------------------------------------
History:		09/05/2012 - Adrian E Dudau - Function created
================================================================================================*/

CREATE FUNCTION [tsql].[fn_list_update] (@list NVARCHAR(MAX),@value NVARCHAR(MAX),@where NVARCHAR(4000))
RETURNS NVARCHAR(MAX) 
AS

BEGIN /*FUNCTION*/
	DECLARE @Result NVARCHAR(MAX) = '';
	DECLARE @item_value NVARCHAR(MAX) = ''

	DECLARE curs CURSOR FOR 
			SELECT 'item_value' = CASE WHEN item_value LIKE @where THEN @value ELSE item_value END  
    		FROM [tsql].[fn_split](@list,',')
		 
	OPEN curs
	FETCH NEXT FROM curs INTO @item_value

	WHILE @@FETCH_STATUS = 0 BEGIN
		SELECT  @result = @result + CASE WHEN @result = '' THEN '' ELSE ',' END + @item_value
		FETCH NEXT FROM curs INTO @item_value
	END

	CLOSE curs
	DEALLOCATE curs
	
	RETURN @Result 
END /*FUNCTION*/

GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
-- Verify completion
----------------------------
IF EXISTS(SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_list_update') BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_list_update - Completed with SUCCESS >>>'
END

ELSE BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_list_update - Completed with ERROR >>>'
END

GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------


