USE Lib
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
----------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_lpad') BEGIN
	DROP  FUNCTION  tsql.fn_lpad
	PRINT '<<< DROP FUNCTION tsql.fn_lpad - Completed with SUCCESS >>>'
END

GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

/*================================================================================================
Name:			tsql.fn_lpad
Type:			User defined function 
Owner:			
Description:	Returns a string left padded to the specified number of characters
Parameters:		@string_to_pad = string to add pad characters to
				@pad_char = character(S) to use for padding
				@pad_to_len = final lenght of the string after padding
Dependens on:  	none
Usage:			SELECT [tsql].[fn_lpad] ('test','z',25)
--------------------------------------------------------------------------------------------------
Project:		http://sqllib.codeplex.com/
Help:			http://sqllib.codeplex.com/wikipage?title=fn_lpad&referringTitle=Documentation		
Version:		20120822
SrcCtrlApp:		SVN
SrcCtrlPath:	http://sqllib.codeplex.com/SourceControl/list/changesets
--------------------------------------------------------------------------------------------------
History:		11/23/2009 - Adrian E Dudau - Function created
History:		11/30/2009 - Adrian E Dudau - Enhanced function for extreme cases
History:		08/22/2012 - Adrian E Dudau - Added references to project, SVN and Help
================================================================================================*/

CREATE FUNCTION [tsql].[fn_lpad] 
	( @string_to_pad NVARCHAR(MAX)
	, @pad_char NVARCHAR(4000)
	, @pad_to_len BIGINT)
RETURNS NVARCHAR(MAX)
AS

BEGIN

	-- Reduce overhead by returning string unchanged
	IF LEN(@string_to_pad) >= @pad_to_len BEGIN 
		SET @pad_char = N''
	END

	RETURN REPLICATE(ISNULL(@pad_char,''),@pad_to_len - LEN(@string_to_pad)) + @string_to_pad 
END

GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
-- Verify completion
----------------------------
IF EXISTS(SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_lpad') BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_lpad - Completed with SUCCESS >>>'
END

ELSE BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_lpad - Completed with ERROR >>>'
END

GO

----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------
