USE Lib
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
----------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_min_val') BEGIN
	DROP  FUNCTION  tsql.fn_min_val
	PRINT '<<< DROP FUNCTION tsql.fn_min_val - Completed with SUCCESS >>>'
END
GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


/*================================================================================================
Name:			tsql.fn_min_val
Type:			User defined function 
Owner:			
Project:			
Description:	Returns min value from a list of values 
Parameters:		@list = list of values comma delimited
				@compare_as = indicates if the list of values is a list of numbers or text
Dependens on:  	fn_split
Usage:			SELECT [tsql].[fn_min_val] ('1,2,3,4,5','number')
--------------------------------------------------------------------------------------------------
Version:		20091202
SrcCtrlApp:		
SrcCtrlPath:	
--------------------------------------------------------------------------------------------------
History:		12/02/2009 - Adrian E Dudau - Function created
================================================================================================*/

CREATE FUNCTION [tsql].[fn_min_val] (@list NVARCHAR(MAX),@compare_as NVARCHAR(50))
RETURNS NVARCHAR(MAX)
AS

BEGIN
	DECLARE @Result AS NVARCHAR(MAX)	

	IF ISNULL(@compare_as,'') IN ('NO','N','NUMBER') BEGIN 
		SET @compare_as = 'NUMBER'
	END	
	ELSE BEGIN
		SET @compare_as = 'STRING'
	END

	-- If the List is empty or null return input string
	SET @Result = @list

	-- Else get min
	IF ISNULL(@list,'') <> '' BEGIN
		SELECT @Result = MIN(CASE WHEN @compare_as = 'NUMBER' AND ISNUMERIC(LTRIM(RTRIM(ISNULL(item_value,'0')))) = 1 THEN 			
									 CAST(item_value AS FLOAT)
								  ELSE item_value	 
							 END)
		FROM tsql.fn_split(@list,',')
	END

	RETURN @Result 
END

GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
-- Verify completion
----------------------------
IF EXISTS(SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_min_val') BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_min_val - Completed with SUCCESS >>>'
END

ELSE BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_min_val - Completed with ERROR >>>'
END

GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------


