USE Lib
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
----------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_range_val') BEGIN
	DROP  FUNCTION  tsql.fn_range_val
	PRINT '<<< DROP FUNCTION tsql.fn_range_val - Completed with SUCCESS >>>'
END
GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


/*================================================================================================
Name:			tsql.fn_range_val
Type:			User defined function 
Owner:					
Description:	Returns the range (max-min) of a numeric list of values  
Parameters:		@list = list of numeric values comma delimited
Dependens on:  	fn_split
Usage:			SELECT [tsql].[fn_range_val] ('1,2,2,2,3,4,5')
--------------------------------------------------------------------------------------------------
Project:		http://sqllib.codeplex.com/
Help:			http://sqllib.codeplex.com/wikipage?title=fn_range_val&referringTitle=Documentation		
Version:		20120906
SrcCtrlApp:		SVN
SrcCtrlPath:	http://sqllib.codeplex.com/SourceControl/list/changesets
--------------------------------------------------------------------------------------------------
History:		09/06/2012 - Adrian E Dudau - Function created
================================================================================================*/

CREATE FUNCTION [tsql].[fn_range_val] (@list NVARCHAR(MAX))
RETURNS FLOAT 
AS

BEGIN
	RETURN (SELECT 'range' = MAX(CAST(item_value AS FLOAT)) - MIN(CAST(item_value AS FLOAT)) FROM tsql.fn_split(@list,','))
END

GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
-- Verify completion
----------------------------
IF EXISTS(SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_range_val') BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_range_val - Completed with SUCCESS >>>'
END

ELSE BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_range_val - Completed with ERROR >>>'
END

GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------


