USE Lib
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
----------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE name = 'fn_smart_replace') BEGIN
	DROP  FUNCTION  tsql.fn_smart_replace
	PRINT '<<< DROP FUNCTION tsql.fn_smart_replace - Completed with SUCCESS >>>'
END
GO

/*================================================================================================
Name:			tsql.fn_smart_replace
Type:			User defined function 
Owner:			
Project:			
Description:	Replace repeated sequesnces chars with length between a min and a max 
Parameters:		
Dependens on:  	none
Usage:			SELECT fn_smart_replace('qwertyyyyasdfggggg','g','',2,4)
--------------------------------------------------------------------------------------------------
Version:		20070503
SrcCtrlApp:		
SrcCtrlPath:	
--------------------------------------------------------------------------------------------------
History:		05/03/2007 - Adrian E Dudau - Function created
History:		08/13/2012 - Adrian E Dudau - Renamed to fn_smart-delete from fn_replace_repetition
================================================================================================*/
CREATE FUNCTION tsql.fn_smart_replace
	(  @string NVARCHAR(4000)
	 , @search_for NVARCHAR(4000)
     , @replace_with NVARCHAR(4000)

	 , @min_replace_len INT = 1
	 , @max_replace_len INT = 4000
	)
RETURNS NVARCHAR(4000)
WITH EXECUTE AS CALLER
AS

BEGIN 
	DECLARE @n AS INT

	IF @min_replace_len < 0 
		SET @min_replace_len = 0

	IF @max_replace_len < @min_replace_len 
		SET @max_replace_len = @min_replace_len 

	SET @n = @max_replace_len

	WHILE @n >= @min_replace_len BEGIN 
		SET @string = REPLACE(@string,REPLICATE(@search_for,@n),@replace_with)
		SET @String = REPLACE(@string,REPLICATE(@replace_with,2),@replace_with)
		SET @n = @n - 1
	END

	RETURN @string
END

GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
-- Verify completion
----------------------------
IF EXISTS(SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_smart_replace') BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_smart_replace - Completed with SUCCESS >>>'
END
ELSE BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_smart_replace - Completed with ERROR >>>'
END

GO

----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------
