USE Lib
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
----------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TF' AND name = 'fn_split_xt') BEGIN
	DROP  FUNCTION  tsql.fn_split_xt
	PRINT '<<< DROP FUNCTION tsql.fn_split_xt - Completed with SUCCESS >>>'
END

GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

/*================================================================================================
Name:			tsql.fn_split_xt
Type:			User defined function 
Owner:					
Description:	Visual basic SPLIT function implementation for TSql, with additional functionality
				for extracting specified item, use of text qualifier, and multichar delimiter 
Parameters:		@list = list of values to be split
				@delimiter = delimiter used to sepparate list items
				@qualifier = text qualifier
				@item_no = List item to retrieve, use 0 for all
Dependens on:  	none
Usage:			SELECT * FROM [Lib].[tsql].[fn_split_xt] ('1;2;3;4;5',';',NULL,0)
--------------------------------------------------------------------------------------------------
Project:		http://sqllib.codeplex.com/
Help:			http://sqllib.codeplex.com/wikipage?title=fn_split_xt&referringTitle=Documentation		
Version:		20120822
SrcCtrlApp:		SVN
SrcCtrlPath:	http://sqllib.codeplex.com/SourceControl/list/changesets
--------------------------------------------------------------------------------------------------
History:		02/02/2007 - Adrian E Dudau - Function created
History:		06/19/2008 - Adrian E Dudau - Added qualifier and field no
History:		06/06/2009 - Adrian E Dudau - Implemented multichar delimiter
History:		01/04/2010 - Adrian E Dudau - Added ID column
History:		03/19/2010 - Adrian E Dudau - Added ItemNo column, extended @List to NVARCHAR(MAX), 
											  improved performance, simplified code.
History:		03/22/2010 - Adrian E Dudau - Added logic for NULL arguments 
History:		08/22/2012 - Adrian E Dudau - Added references to project, SVN and Help
================================================================================================*/

CREATE FUNCTION [tsql].[fn_split_xt] 
	( @list NVARCHAR(MAX)
	, @delimiter NVARCHAR(255) = ' ' 
	, @qualifier NVARCHAR(255) = ''
	, @item_no BIGINT = 0
	)
RETURNS @Result TABLE (id BIGINT IDENTITY(1,1),item_no BIGINT,item_value NVARCHAR(4000)) AS

BEGIN
	DECLARE @CurPos AS BIGINT 
	DECLARE @LastPos AS BIGINT 
	DECLARE @Len AS BIGINT 
	DECLARE @Item AS BIGINT  

	-- Check for argument anomalies
	IF ISNULL(@list,'') = '' RETURN

	IF ISNULL(@delimiter,'') = '' BEGIN  	 
		INSERT INTO @Result(item_no,item_value)
		VALUES(1,@list)

		RETURN
	END

	-- Remove Qualifier 
	SET @list = REPLACE(@list,ISNULL(@qualifier,''), '')
	-- Replace delimiter to allow words
	SET @list = REPLACE(@list,@delimiter, CHAR(232)) 
	SET @delimiter = CHAR(232)

	-- Parse the entire list 
	WHILE ISNULL(@CurPos,1) > 0 BEGIN 
		-- Increment  the item counter 
		SET @Item = ISNULL(@Item,0) + 1

		-- Calculate position and lenght 
		SET @CurPos = CHARINDEX(@delimiter,@list,ISNULL(@LastPos,0))
		SET @Len = @CurPos - isnull(@LastPos,0)

		-- Last Item in list adjustment	
		IF @Len < 0 SET @Len = 999999999  

		-- Get item no x or all items  
		IF @Item = @item_no OR @item_no = 0 BEGIN 
			INSERT INTO @Result(Item_no,item_value)
			VALUES(@Item,SUBSTRING(@list,isnull(@LastPos,0),@Len))
		END

		-- Exits the loop if only one item is required 
		-- in order to improve performance
		IF @Item > @item_no AND @item_no > 0 BREAK

		-- Store last position
		SET @LastPos = @CurPos + 1
	END /*WHILE*/

	RETURN 
END /*FUNCTION*/

GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
-- Verify completion
----------------------------

IF EXISTS(SELECT * FROM sysobjects WHERE type = 'TF' AND name = 'fn_split_xt') BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_split_xt - Completed with SUCCESS >>>'
END

ELSE BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_split_xt - Completed with ERROR >>>'
END


GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

-- GRANT SELECT TO PUBLIC will be used at Db level



