USE Lib
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
----------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'sp_partition_scheme_name') BEGIN
	DROP PROCEDURE tsql.sp_partition_scheme_name
	PRINT '<<< DROP PROCEDURE tsql.sp_partition_scheme_name - Completed with SUCCESS >>>'
END

GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

/*================================================================================================
Name:			tsql.sp_partition_scheme_name
Type:			User defined procedure 
Owner:			
Description:	returns the partition scheme name for a given table in specified schema/database
Parameters:		@object_name = table/index name   
				@object_type = specifies in objet is table or index
				@parent_name = name of the parent object, schema for table and table for index
				@db_name = database where object resides
				@partition_scheme_name = OUTPUT of sproc
Dependens on:  	none
Usage:			DECLARE @ps_name sysname

				EXECUTE tsql.sp_partition_scheme_name  
				   @object_name = 'country'
				  ,@object_type = 'TABLE'
				  ,@parent_name = 'dbo'
				  ,@db_name = 'Lib'
				  ,@partition_scheme_name = @ps_name OUTPUT

				SELECT @ps_name 
--------------------------------------------------------------------------------------------------
Project:		http://sqllib.codeplex.com/
Help:			http://sqllib.codeplex.com/wikipage?title=sp_partition_scheme_name&referringTitle=Documentation		
Version:		20120822
SrcCtrlApp:		SVN
SrcCtrlPath:	http://sqllib.codeplex.com/SourceControl/list/changesets
--------------------------------------------------------------------------------------------------
History:		06/22/2007 - Adrian E Dudau - Procedure created
History:		08/22/2012 - Adrian E Dudau - Added references to project, SVN and Help
================================================================================================*/

CREATE PROCEDURE tsql.[sp_partition_scheme_name]
	(
	  @object_name SYSNAME
	, @object_type SYSNAME = 'TABLE'
	, @parent_name SYSNAME = 'dbo'
	, @db_name SYSNAME = NULL
	, @partition_scheme_name SYSNAME = '' OUTPUT  
	)
AS
BEGIN
	DECLARE @SQL AS NVARCHAR(MAX) 

	IF LEN(ISNULL(@db_name,'')) = 0 
		SET @db_name = DB_NAME(); 

	IF LEN(ISNULL(@parent_name,'')) = 0 
		SET @parent_name = 'dbo'; 
	
	IF LEN(ISNULL(@object_type,'')) = 0 
		SET @object_type = 'TABLE'; 
	
	
	-- FOR TABLES
	IF UPPER(@object_type) IN('U','TABLE') BEGIN 
		SET @SQL = 'SELECT DISTINCT TOP 1 @PartSchemeName = ps.name 
					FROM ' + @db_name + '.sys.partitions p 
					INNER JOIN ' + @db_name + '.sys.tables t 
						ON p.[object_id] = t.[object_id] 
					INNER JOIN ' + @db_name + '.sys.schemas s 
						ON t.[schema_id] = s.[schema_id] 
					INNER JOIN ' + @db_name + '.sys.indexes i 
						ON p.[object_id] = i.[object_id] 
						AND p.index_id = i.index_id 
					INNER JOIN ' + @db_name + '.sys.data_spaces d 
						ON i.data_space_id = d.data_space_id 
					INNER JOIN ' + @db_name + '.sys.partition_schemes ps 
						ON d.data_space_id = ps.data_space_id 
					INNER JOIN ' + @db_name + '.sys.partition_functions pf 
						ON PS.function_id = pf.function_id  	
					WHERE s.name = ''' + @parent_name + '''
						AND t.name = ''' + @object_name + ''''
	END
	ELSE IF @object_type IN('I','INDEX') BEGIN 
		SET @SQL = 'SELECT DISTINCT TOP 1 @PartSchemeName = ps.name 
					FROM ' + @db_name + '.sys.partitions p 
					INNER JOIN ' + @db_name + '.sys.tables t 
						ON p.[object_id] = t.[object_id] 
					INNER JOIN ' + @db_name + '.sys.schemas s 
						ON t.[schema_id] = s.[schema_id] 
					INNER JOIN ' + @db_name + '.sys.indexes i 
						ON p.[object_id] = i.[object_id] 
						AND p.index_id = i.index_id 
					INNER JOIN ' + @db_name + '.sys.data_spaces d 
						ON i.data_space_id = d.data_space_id 
					INNER JOIN ' + @db_name + '.sys.partition_schemes ps 
						ON d.data_space_id = ps.data_space_id 
					INNER JOIN ' + @db_name + '.sys.partition_functions pf 
						ON PS.function_id = pf.function_id  	
					WHERE i.name = ''' + @object_name + '''
						AND i.[object_id] = OBJECT_ID(''' + @parent_name + ''')'
	END	
	ELSE 
		SET @SQL = '	SELECT @PartSchemeName = NULL'
	
	
	EXECUTE sp_executesql @SQL, N'@PartSchemeName SYSNAME OUTPUT', @PartSchemeName = @partition_scheme_name OUTPUT;
	RETURN 0	
END
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
-- Verify completion
----------------------------
IF EXISTS(SELECT * FROM sysobjects WHERE type = 'P' AND name = 'sp_partition_scheme_name') BEGIN 
	PRINT '<<< CREATE PROCEDURE tsql.sp_partition_scheme_name - Completed with SUCCESS >>>'
END

ELSE BEGIN 
	PRINT '<<< CREATE PROCEDURE tsql.sp_partition_scheme_name - Completed with ERROR >>>'
END


GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

--  GRANT SELECT TO PUBLIC will be used at Db level
