USE Lib
GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
----------------------------
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_nth_val') BEGIN
	DROP  FUNCTION  tsql.fn_nth_val
	PRINT '<<< DROP FUNCTION tsql.fn_nth_val - Completed with SUCCESS >>>'
END
GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


/*================================================================================================
Name:			tsql.fn_nth_val
Type:			User defined function 
Owner:					
Description:	Returns the nth value from a coma sepparated list of values 
Parameters:		@list = list of values comma delimited
				@no = nth value to be retrieved 
Dependens on:  	fn_split_xt
Usage:			SELECT [tsql].[fn_nth_val] ('1,2,3,4,5',6)
--------------------------------------------------------------------------------------------------
Project:		http://sqllib.codeplex.com/
Help:			http://sqllib.codeplex.com/wikipage?title=fn_nth_val&referringTitle=Documentation		
Version:		20120904
SrcCtrlApp:		SVN
SrcCtrlPath:	http://sqllib.codeplex.com/SourceControl/list/changesets
--------------------------------------------------------------------------------------------------
History:		09/04/2012 - Adrian E Dudau - Function created
================================================================================================*/

CREATE FUNCTION [tsql].[fn_nth_val] (@list NVARCHAR(MAX), @no BIGINT)
RETURNS NVARCHAR(MAX)
AS

BEGIN
	RETURN (SELECT item_value FROM tsql.[fn_split_xt](@list,',',NULL,@no)) 
END

GO

---------------------------------------------------------------------------
-- BEGIN MAINTENANCE WRAPPER
-- Verify completion
----------------------------
IF EXISTS(SELECT * FROM sysobjects WHERE type = 'FN' AND name = 'fn_nth_val') BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_nth_val - Completed with SUCCESS >>>'
END

ELSE BEGIN 
	PRINT '<<< CREATE FUNCTION tsql.fn_nth_val - Completed with ERROR >>>'
END

GO
----------------------------
-- END MAINTENANCE WRAPPER
---------------------------------------------------------------------------


